# jqtui
jqtui is a TUI (Text User Interface) for jq.  

The TUI makes it easy to explore json files using jq.

# Installing

Install with `pip`:
```
pip install jqtui
```

Alternatively, install with [pipx](https://pypa.github.io/pipx/):
```
pipx install jqtui
```

# Usage
Run the following to launch jqtui:
```
jqtui <name of JSON filename>
```
